events property
Every motion, prediction, correction, body action, device, and pad event.
Implementation
@override
Stream<StyletEvent> get events => _events ??= eventChannel
.receiveBroadcastStream()
.expand(decodeStyletEvents);
Every motion, prediction, correction, body action, device, and pad event.
@override
Stream<StyletEvent> get events => _events ??= eventChannel
.receiveBroadcastStream()
.expand(decodeStyletEvents);