isSupported property
bool
get
isSupported
Whether the current browser exposes the experimental Ink API.
Implementation
static bool get isSupported => _browserInk() != null;
Whether the current browser exposes the experimental Ink API.
static bool get isSupported => _browserInk() != null;