presentationArea property
Element
presentationArea
final
Element bounding the area where delegated ink may be displayed.
Implementation
final web.Element presentationArea;
Element bounding the area where delegated ink may be displayed.
final web.Element presentationArea;